#include "Messages.h"
#include "RPGApp.h"
#include "RPGWindow.h"



//--------------------------------------------------
//	Implementation of the RPGWindow class
//--------------------------------------------------

// A big happy constructor
RPGWindow::RPGWindow(BRect frame, char *title)
	: BWindow(	frame, title, B_TITLED_WINDOW,
				B_NOT_RESIZABLE | B_NOT_ZOOMABLE)
{
	// Add the menu
	BRect		menuframe = Bounds();
	BMenuBar	*menubar;
	BMenu		*menu;
	
	menubar = new BMenuBar(menuframe, "menubar");
	
	menu = new BMenu("File");
	menu->AddItem(new BMenuItem("Quit", new BMessage(MENU_FILE_QUIT), 'Q'));
	menubar->AddItem(menu);
	
	menu = new BMenu("Help");
	menu->AddItem(new BMenuItem("About...", new BMessage(MENU_HELP_ABOUT), 'A'));
	menubar->AddItem(menu);
	
	AddChild(menubar);
	
	// Add the chexboxes
	BCheckBox *checkBox;
	checkBox = new BCheckBox(BRect(20, 30, 160, 20), "Upper case box",
			"Include upper case letters", new BMessage(UPPER_CASE_BOX));
	if (((RPGApp *)be_app)->UpperCase()) checkBox->SetValue(B_CONTROL_ON);
	AddChild(checkBox);
	
	checkBox = new BCheckBox(BRect(20, 50, 160, 20), "Lower case box",
			"Include lower case letters", new BMessage(LOWER_CASE_BOX));
	if (((RPGApp *)be_app)->LowerCase()) checkBox->SetValue(B_CONTROL_ON);
	AddChild(checkBox);
	
	checkBox = new BCheckBox(BRect(20, 70, 160, 20), "Numbers box",
			"Include numbers", new BMessage(NUMBERS_BOX));
	if (((RPGApp *)be_app)->Numbers()) checkBox->SetValue(B_CONTROL_ON);
	AddChild(checkBox);
	
	// Add the TextControls
	fDigitNbTextControl = new BTextControl(BRect(185, 30, 480, 0), "DigitNb text control",
			"Number of digits per password", "", new BMessage(TC_DIGIT_NB));
	BString DigitNb;
	DigitNb<<((RPGApp *)be_app)->DigitNb();
	fDigitNbTextControl->SetText(DigitNb.String());
	AddChild(fDigitNbTextControl);
	
	fPassWdNbTextControl = new BTextControl(BRect(185, 50, 480, 0), "PassWdNb text control",
			"Number of passwords", "", new BMessage(TC_PASSWD_NB));
	BString PasswordNb;
	PasswordNb<<((RPGApp *)be_app)->PassWdNb();
	fPassWdNbTextControl->SetText(PasswordNb.String());
	AddChild(fPassWdNbTextControl);
	
	// Add the button
	BButton *button;
	button = new BButton(BRect(20, 95, 480, 0), "Button",
			"Generate", new BMessage(BUTTON_PRESSED));
	AddChild(button);	
}

// Process the messages received by the application
void RPGWindow::MessageReceived(BMessage *message)
{
	switch (message->what)
	{
		case MENU_FILE_QUIT:
			be_app->PostMessage(B_QUIT_REQUESTED);
			break;
		
		case MENU_HELP_ABOUT:
			be_app->PostMessage(B_ABOUT_REQUESTED);
			break;
		
		case UPPER_CASE_BOX:
			((RPGApp *)be_app)->ChangeUpperCase();
			break;
		
		case LOWER_CASE_BOX:
			((RPGApp *)be_app)->ChangeLowerCase();
			break;
		
		case NUMBERS_BOX:
			((RPGApp *)be_app)->ChangeNumbers();
			break;
		
		case TC_DIGIT_NB:
			{
				int32 digitNb;
				digitNb = atoi(fDigitNbTextControl->Text());
				if (digitNb <= 0)
					((RPGApp *)be_app)->Alert("Please enter an interger greater than zero",
						"Ok", B_WARNING_ALERT);
				((RPGApp *)be_app)->SetDigitNb(digitNb);
			}
			break;
		
		case TC_PASSWD_NB:
			{
				int32 passwordNb;
				passwordNb = atoi(fPassWdNbTextControl->Text());
				if (passwordNb <= 0)
					((RPGApp *)be_app)->Alert("Please enter an interger greater than zero",
						"Ok", B_WARNING_ALERT);
				((RPGApp *)be_app)->SetPassWdNb(passwordNb);
			}
			break;
		
		case BUTTON_PRESSED:
			if (!((RPGApp *)be_app)->UpperCase() &&
				!((RPGApp *)be_app)->LowerCase() &&
				!((RPGApp *)be_app)->Numbers())
			{
				((RPGApp *)be_app)->Alert("You must choose at least one of the three:\n\n"
					"upper case letters\n"
					"lower case letters\n"
					"or numbers",
					"I think that too...", B_WARNING_ALERT);
				break;
			}
			((RPGApp *)be_app)->GeneratePasswords();
			break;
		
		default:
			BWindow::MessageReceived(message);
			break;
	}
}

// Have to quit...
bool RPGWindow::QuitRequested()
{
	be_app->PostMessage(B_QUIT_REQUESTED);
	return BWindow::QuitRequested();
}
